%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*-(.*?)$/$1/g')}}

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Modules.symvers

Name:         vmware-tools-vmci
BuildRequires: kernel-source kernel-syms gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmci kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      9.0.3.0
Release:      3
Source1:      vmci-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

Source0:      vmci.tar
Source2:      vmci-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*)-.*?$/$1/g')

%define vmware_use_symvers_file 1

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*-(.*)$/$1/g')}
%suse_kernel_module_package -s %{SOURCE2} -x %{current_flavor}

%prep
%setup -n vmci-only

%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.3.0-%{kernel_version}-$flavor

  rm -rf ../$flavor ../vmci.o
  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor clean

  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vmci" = "vsock" -o "vmci" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/packages/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor
  mkdir ../$flavor
  cp ../vmci.o ../$flavor

  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vmci_SYMVERS_FILE=%{vmw_symvers_dir}/vmci-9.0.3.0-%{kernel_version}-$flavor
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vmci.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}-$flavor/updates/vmci.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vmci_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmci.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%package common
Summary:      Contains the common files used by all the vmci kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.5
Release:      3
Version:      8.6.5

%description common
 This package contains the common system configuration and scripts responsible for loading the vmci kernel module.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/insserv -r vmci >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VMCI_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,10 --dbAddAnswer VMCI_NAME,vmci
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl --os=linux,sle,10 --kernel=%{kernel_version} --toConfigure=vmci
if [ -e /etc/init.d/vmci ]; then
   /sbin/insserv -f vmci >/dev/null 2>&1
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/insserv -r vmci >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VMCI_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl
/etc/init.d/vmci
%dir /usr/lib/vmware-tools/moduleScripts/vmci
%dir /usr/lib/vmware-tools/moduleScripts
%dir /usr/lib/vmware-tools
%dir /usr/lib
%dir /usr
%dir /etc/init.d
%dir /etc
